from loguru import logger
import argparse
import configparser
import threading
from queue import Queue

from GenericMqttSubscriber import GenericMqttSubscriber


deathBell = threading.Event()

def exceptHook(args):
    global deathBell
    logger.error("Exception in thread caught: {}".format(args))
    deathBell.set()
    logger.error("rang the death bell")

# ------------------------------------------------------------------------------
logger.info("IIoTFeeder2 starting")

parser = argparse.ArgumentParser(description="IIoTFeeder2")
parser.add_argument('--config', '-f',
                    help='Config file, default is $pwd/config/config.ini',
                    required=False,
                    default='./config/config.ini')
args = parser.parse_args()

config = configparser.ConfigParser()
config.read(args.config)

# ------------------------------------------------------------------------------
masterQueue = Queue()
masterSubscriber = GenericMqttSubscriber(config, "master", masterQueue)
masterSubscriber.start()
logger.debug("MasterSubscriber started")

# ------------------------------------------------------------------------------
threading.excepthook = exceptHook
logger.debug("Threading excepthook set")

logger.debug("IIoTFeeder2 running")

# ------------------------------------------------------------------------------
while not deathBell.wait(1.0):
    logger.debug("master queue size {}".format(masterQueue.qsize()))

logger.error("IIoTFeeder2 is dying")

masterSubscriber.stop()

masterSubscriber.join()
logger.error("masterSubscriber joined")

# ------------------------------------------------------------------------------
logger.info("IIoTFeeder2 to terminate")


